[PATCH] D69001: [NFC][XCOFF][AIX] Rename ControlSections to CsectGroup

Jason Liu via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Wed Oct 16 10:37:49 PDT 2019


This revision was automatically updated to reflect the committed changes.
Closed by commit rG97ed5625442d: [NFC][XCOFF][AIX] Rename ControlSections to CsectGroup (authored by jasonliu).

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D69001/new/

https://reviews.llvm.org/D69001

Files:
  llvm/lib/MC/XCOFFObjectWriter.cpp


Index: llvm/lib/MC/XCOFFObjectWriter.cpp
===================================================================
--- llvm/lib/MC/XCOFFObjectWriter.cpp
+++ llvm/lib/MC/XCOFFObjectWriter.cpp
@@ -115,7 +115,7 @@
   // (approximately) the same storage mapping class. For example all the csects
   // with a storage mapping class of `xmc_pr` will get placed into the same
   // container.
-  using ControlSections = std::deque<ControlSection>;
+  using CsectGroup = std::deque<ControlSection>;
 
   support::endian::Writer W;
   std::unique_ptr<MCXCOFFObjectTargetWriter> TargetObjectWriter;
@@ -129,11 +129,11 @@
   Section Text;
   Section BSS;
 
   // ControlSections. These store the csects which make up different parts of
   // the sections. Should have one for each set of csects that get mapped into
   // the same section and get handled in a 'similar' way.
-  ControlSections ProgramCodeCsects;
-  ControlSections BSSCsects;
+  CsectGroup ProgramCodeCsects;
+  CsectGroup BSSCsects;
 
   uint32_t SymbolTableEntryCount = 0;
   uint32_t SymbolTableOffset = 0;


-------------- next part --------------
@@ -129,11 +129,11 @@
   Section BSS;
 
-  // ControlSections. These store the csects which make up different parts of
+  // CsectGroups. These store the csects which make up different parts of
   // the sections. Should have one for each set of csects that get mapped into
   // the same section and get handled in a 'similar' way.
A non-text attachment was scrubbed...
Name: D69001.225258.patch
Type: text/x-patch
Size: 1135 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20191016/3c636b87/attachment.bin>


More information about the llvm-commits mailing list